Releases
********

We don't use semantic versioning.  The first number indicates that we have
made a major API break (e.g., 1.x to 2.x), which happens rarely.
The point releases are new versions and may contain minor API breakage.
Usually, this happens after a two cycle deprecation period.

.. warning::
   Since we don't normally make bug-fix only releases, it may not make sense
   for you to use ``~=`` as a pip version specifier.

.. toctree::
   :maxdepth: 2

   release_dev
   release_3.4.2
   release_3.4.1
   release_3.4
   release_3.3
   release_3.2.1
   release_3.2
   release_3.1
   release_3.0
   release_2.8.8
   release_2.8.7
   release_2.8.6
   release_2.8.5
   release_2.8.4
   release_2.8.3
   release_2.8.2
   release_2.8.1
   release_2.8
   release_2.7.1
   release_2.7
   release_2.6
   release_2.5
   release_2.4
   release_2.3
   release_2.2
   release_2.1
   release_2.0
   api_1.11
   api_1.10
   api_1.9
   api_1.8
   api_1.7
   api_1.6
   api_1.5
   api_1.4
   api_1.0
   api_0.99
   old_release_log
